<no title> — cis_interface 0.3.0 documentation

Model YAML:

    1
    2
    3
    4
    5
    6
    7
    ---

    model:
      name: server
      language: python
      args: ./src/server.py
      is_server: True  # Creates a RPC server queue called "server"

     1
     2
     3
     4
     5
     6
     7
     8
     9
    10
    11
    12
    13
    14
    15
    16
    17
    18
    19
    20
    21
    22
    23
    24
    25
    26
    27
    ---

    models:
      - name: client1
        language: python
        args:
          - ./src/client.py
          - 3  # Pass the number of iterations that should be performed
          - 1  # Pass index of the client
        client_of: server  # Creates an RPC client queue "server_client"
        outputs: output_log1
      - name: client2
        language: python
        args:
          - ./src/client.py
          - 5  # Pass the number of iterations that should be performed
          - 2  # Pass index of the client
        client_of: server  # Creates an RPC client queue "server_client"
        outputs: output_log2

    connections:
      - input: output_log1
        output: client_output1.txt
        in_temp: True
      - input: output_log2
        output: client_output2.txt
        in_temp: True

(Example in other languages)